==> splight_cli-5.3.1-py3-none-any.whl: splight_cli/cli.py <==
from typing import Optional

import typer
from rich.console import Console

from splight_cli.component import component_app
from splight_cli.config import config_app
from splight_cli.constants import error_style
from splight_cli.context import Context
from splight_cli.context.workspace import ConfigurationError
from splight_cli.engine import engine_app
from splight_cli.hub import hub_app
from splight_cli.version import __version__
from splight_cli.workspace import workspace_app

console = Console()
app = typer.Typer(
    name="Splight Command Line",
    add_completion=True,
    rich_markup_mode="rich",
    invoke_without_command=True,
    pretty_exceptions_enable=False,
)

app.add_typer(config_app, name="configure")
app.add_typer(component_app, name="component")
app.add_typer(engine_app, name="engine")
app.add_typer(hub_app, name="hub")
app.add_typer(workspace_app, name="workspace")


def version_callback(version: bool):
    if version:
        print(__version__)
        raise typer.Exit()


@app.callback()
def main(
    ctx: typer.Context,
    version: Optional[bool] = typer.Option(
        None, "--version", "-v", callback=version_callback, is_eager=True
    ),
) -> None:
    try:
        ctx.obj = Context(
            new_workspace=(
                True if ctx.invoked_subcommand == "configure" else False
            )
        )
    except ConfigurationError as exc:
        console.print(
            (
                f"Error running Splight: {str(exc)}. "
                "Run command 'splight configure' to configure your environment"
            ),
            style=error_style,
        )
        raise typer.Exit(code=1)
    if ctx.invoked_subcommand is None:
        ctx.get_help()

==> splight_cli-5.4.0-py3-none-any.whl: splight_cli/cli.py <==
from typing import Optional

import typer
from rich.console import Console
from splight_lib.settings import workspace_settings

from splight_cli.component import component_app
from splight_cli.config import config_app
from splight_cli.engine import engine_app
from splight_cli.hub import hub_app
from splight_cli.version import __version__
from splight_cli.workspace import workspace_app

console = Console()

app = typer.Typer(
    name="Splight Command Line",
    add_completion=True,
    rich_markup_mode="rich",
    pretty_exceptions_enable=False,
)


app.add_typer(config_app, name="configure")
app.add_typer(component_app, name="component")
app.add_typer(engine_app, name="engine")
app.add_typer(hub_app, name="hub")
app.add_typer(workspace_app, name="workspace")


def ensure_settings(ctx: typer.Context):
    if not workspace_settings.configured:
        console.print(
            "Please run `splight configure` or set the corresponding environment variables.",
            style="red",
        )
        raise typer.Exit(code=1)


@app.callback(invoke_without_command=True)
def main(
    ctx: typer.Context,
    version: Optional[bool] = typer.Option(
        None, "--version", "-v", is_eager=True
    ),
) -> None:
    if version:
        console.print(__version__)
        raise typer.Exit()

    command = ctx.invoked_subcommand

    if command and command not in [
        "workspace",
        "configure",
    ]:
        # Forward the check to every sub command
        ensure_settings(ctx)

    if command is None:
        ctx.get_help()
